@@ -109,10 +109,13 @@ block_exec = function(options) {
     res.after = run_hooks(before = FALSE, options)
     output = paste(c(res.before, output, res.after), collapse = '')
     output = knit_hooks$get('chunk')(output, options)
-    if (options$cache) block_cache(options, output, switch(
-      options$engine,
-      'stan' = options$output.var, 'sql' = options$output.var, character(0)
-    ))
+    if (options$cache) {
+      cache.exists = cache$exists(options$hash, options$cache.lazy)
+      if (options$cache.rebuild || !cache.exists) block_cache(options, output, switch(
+        options$engine,
+        'stan' = options$output.var, 'sql' = options$output.var, character(0)
+        ))
+      }
     return(if (options$include) output else '')
   }
 
